# onionpp

embed tor in your application

## features

- [X] start tor
- [X] python bindings

## usage

```c++
#include "onionpp.h"

int main() {
  onionpp::Tor tor;

  // use the tor socks port
  return 0;
}
```
